@@ -18,7 +18,7 @@ bcmaps_env <- new.env(parent = emptyenv())
 
 
 bcmapsStartupMessage <- function() {
-  msg <- "Support for Spatial objects (`sp`) was deprecated in {bcmaps} v1.2.0, and will be removed altogether in the Summer 2023. Please use `sf` objects with {bcmaps}."
+  "Support for Spatial objects (`sp`) was removed in {bcmaps} v2.0.0. Please use `sf` objects with {bcmaps}."
 }
 
 .onAttach <- function(lib, pkg)
@@ -28,15 +28,3 @@ bcmapsStartupMessage <- function() {
   packageStartupMessage(msg)
   invisible()
 }
-
-deprecate_sp <- function(what,
-                         env = rlang::caller_env(),
-                         user_env = rlang::caller_env(2)) {
-  lifecycle::deprecate_warn(
-    when = "1.2.0",
-    what = what,
-    details = "Please use `sf` objects with {bcmaps}, support for Spatial objects (sp) will be removed in Summer 2023.",
-    env = env,
-    user_env = user_env
-  )
-}
